package com.huimv.farm.musk.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.farm.musk.common.utils.DataUill;
import com.huimv.farm.musk.common.utils.Result;
import com.huimv.farm.musk.common.utils.ResultCode;
import com.huimv.farm.musk.entity.DevEnergy;
import com.huimv.farm.musk.entity.DevEnv;
import com.huimv.farm.musk.entity.SysCameraArea;
import com.huimv.farm.musk.mapper.DevEnergyMapper;
import com.huimv.farm.musk.mapper.DevEnvMapper;
import com.huimv.farm.musk.service.IDevEnergyService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author author
 * @since 2024-09-02
 */
@Service
public class DevEnergyServiceImpl extends ServiceImpl<DevEnergyMapper, DevEnergy> implements IDevEnergyService {

    @Autowired
    private DevEnergyMapper energyMapper;

    @Override
    public Result pageEnergy(Map<String, Object> map) {

        Integer current = (Integer) map.get("current");
        Integer size = (Integer) map.get(" ");
        String farmId = (String) map.get("farmId");
        String unitId = (String) map.get("unitId");

        IPage<DevEnergy> list = page(new Page<>(current, size), new QueryWrapper<DevEnergy>().eq(StringUtils.isNotBlank(unitId),"unit_id",unitId).eq("farm_id", farmId));

        return new Result(ResultCode.SUCCESS, list);
    }

    @Override
    public Result listEnergy(Map<String, String> map) {
        String startDate = map.get("startDate");
        String endDate = map.get("endDate");
        String unitId = map.get("unitId");
        return new Result(ResultCode.SUCCESS, this.list( new QueryWrapper<DevEnergy>().eq(StringUtils.isNotBlank(unitId),"unit_id",unitId)
                .ge(StringUtils.isNotBlank(startDate),"date_time",startDate).le(StringUtils.isNotBlank(endDate),"date_time",endDate)));

    }

    @Override
    public Result listHistory(Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String unitId = paramsMap.get("unitId");
        String timeType = paramsMap.get("timeType");

        if ("".equals(timeType) || null == timeType) {
            timeType = "1";
        }
        QueryWrapper<DevEnv> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).eq("unit_id", unitId);
        //今日
        List<DevEnergy> protEnvData =null ;
        if ("1".equals(timeType)) {
            Date timesmorning = DataUill.getTimesmorning();
            queryWrapper.ge("create_time", timesmorning);
            protEnvData = energyMapper.listDataDay(queryWrapper);
        }
        //本周
        else if ("2".equals(timeType)) {
            DateTime dateTime = DateUtil.beginOfWeek(new Date());
            queryWrapper.ge("create_time", dateTime);
            protEnvData = energyMapper.listData(queryWrapper);
        }
        //本月
        else if ("3".equals(timeType)) {
            Date monthmorning = DataUill.getTimesMonthmorning();
            queryWrapper.ge("create_time", monthmorning);
            protEnvData = energyMapper.listData(queryWrapper);
        }
        //自定义
        else if ("4".equals(timeType)) {
            String startDate = paramsMap.get("startDate");
            String endDate = paramsMap.get("endDate");
            queryWrapper.between("create_time", startDate, endDate);
            protEnvData = energyMapper.listData(queryWrapper);
        }
        return new Result(ResultCode.SUCCESS, protEnvData);
    }
}
